<?php

/**
* Plugin Name: eStore Download via Text Link
* Plugin URI: http://www.tipsandtricks-hq.com
* Description: eStore addon for downloading product using text link
* Version: 1.6
* Author: Tips and Tricks HQ
* Author URI: http://www.tipsandtricks-hq.com/
* Requires at least: 3.0
*/

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('ESTORE_DOWNLOAD_VIA_TEXT_LINK')) {

    class ESTORE_DOWNLOAD_VIA_TEXT_LINK {

        var $version = '1.6';
        var $db_version = '1.0';
        var $plugin_url;
        var $plugin_path;

        function __construct() {
            $this->define_constants();
            $this->includes();
            $this->loader_operations();
        }

        function define_constants() {
            define('ESTORE_DOWNLOAD_VIA_TEXT_LINK_VERSION', $this->version);
            define('ESTORE_DOWNLOAD_VIA_TEXT_LINK_URL', $this->plugin_url());
            define('ESTORE_DOWNLOAD_VIA_TEXT_LINK_PATH', $this->plugin_path());
        }

        function includes() {
            
        }

        function loader_operations() {
            add_action('wp_loaded', array($this, 'plugins_loaded_handler'));   //plugins loaded hook
        }

        function plugins_loaded_handler() {  //Runs when plugins_loaded action gets fired
            if (isset($_GET['wp_eStore_download_now_with_stamping'])) {
                $product_id = strip_tags($_GET['wp_eStore_download_now_with_stamping']);
                eStore_dntl_process_download_with_pdf_stamping($product_id);
                exit;
            }

            if (isset($_GET['wp_eStore_download_now'])) {
                //sanitize data
                $product_id = strip_tags($_GET['wp_eStore_download_now']);

                //Do zero price check first.
                eStore_dnlt_do_zero_price_check($product_id);                
                
                //update the inventory count of this product
                global $wpdb;
                $products_table_name = WP_ESTORE_PRODUCTS_TABLE_NAME;
                $retrieved_product = $wpdb->get_row("SELECT * FROM $products_table_name WHERE id = '$product_id'", OBJECT);
    
                //
                $product_name_with_var_text = $retrieved_product->name;
                $var3 = "";
                if (isset($_GET['variation3'])) {
                    $var3 = strip_tags($_GET['variation3']);
                    $product_name_with_var_text .= "(" . $var3 . ")";
                }
                if (!empty($retrieved_product->variation3) && empty($var3)) {
                    echo '<div class="eStore_error_message">Error! You need to specify a digital variation in order to download this product!</div>';
                    exit;
                }
                //
                $cart_item_qty = 1;
                if (is_numeric($retrieved_product->available_copies)) {
                    $new_available_copies = ($retrieved_product->available_copies - $cart_item_qty);
                }
                $new_sales_count = ($retrieved_product->sales_count + $cart_item_qty);
                $current_product_id = $retrieved_product->id;
                $updatedb = "UPDATE $products_table_name SET available_copies = '$new_available_copies', sales_count = '$new_sales_count' WHERE id='$current_product_id'";
                $results = $wpdb->query($updatedb);
                $download_link = generate_download_link_for_product($product_id, $product_name_with_var_text);
                $pieces = explode("http", $download_link);
                $full_encrypted_url = 'http' . $pieces[1];
                eStore_redirect_to_url($full_encrypted_url);
            }
        }

        function plugin_url() {
            if ($this->plugin_url)
                return $this->plugin_url;
            return $this->plugin_url = plugins_url(basename(plugin_dir_path(__FILE__)), basename(__FILE__));
        }

        function plugin_path() {
            if ($this->plugin_path)
                return $this->plugin_path;
            return $this->plugin_path = untrailingslashit(plugin_dir_path(__FILE__));
        }

        function plugin_init() {//Gets run with WP Init is fired
        }

        //Add your implementation
    }

    //End of plugin class
}//End of class not exists check

$GLOBALS['ESTORE_DOWNLOAD_VIA_TEXT_LINK'] = new ESTORE_DOWNLOAD_VIA_TEXT_LINK();

function eStore_dntl_process_download_with_pdf_stamping($product_id) {
  
    //Check that the user is logged into the site
    if(class_exists('Emember_Auth')){
        $auth = Emember_Auth::getInstance();
    }
    else {
        echo "Error! WP eMember plugin's Emember_Auth class isn't loaded. Check if WP eMember plugin is active.";
        exit;        
    }

    $user_id = $auth->getUserInfo('member_id');
    if (empty($user_id)) {
        echo 'Error! You are not logged in as a member. Only logged in members can use this download with stamping option!';
        exit;
    }

    //Do zero price check first.
    eStore_dnlt_do_zero_price_check($product_id);
    
    $txn_id = uniqid();
    $payment_data = array(
        'first_name' => $auth->getUserInfo('first_name'),
        'last_name' => $auth->getUserInfo('last_name'),
        'payer_email' => $auth->getUserInfo('email'),
        'contact_phone' => $auth->getUserInfo('phone'),
        'address_street' => $auth->getUserInfo('address_street'),
        'address_city' => $auth->getUserInfo('address_city'),
        'address_state' => $auth->getUserInfo('address_state'),
        'address_zip' => $auth->getUserInfo('address_zipcode'),
        'address_country' => $auth->getUserInfo('country'),
        'payer_business_name' => $auth->getUserInfo('company_name'),
        'txn_id' => $txn_id,
    );
    
    global $wpdb;
    $products_table_name = WP_ESTORE_PRODUCTS_TABLE_NAME;
    $ret_product = $wpdb->get_row("SELECT * FROM $products_table_name WHERE id = '$product_id'", OBJECT);

    $cart_item_name = $ret_product->name;


    $download_key = eStore_check_stamping_flag_and_generate_download_key($ret_product, $product_id, '', $payment_data, $cart_item_name);
    $eStore_download_link = eStore_construct_raw_encrypted_dl_url($download_key);
    
    $download_item = stripslashes($cart_item_name) . " - " . $eStore_download_link;
    eStore_register_link_in_db('', $download_key, $download_item, '', '', '', 0, $txn_id);

    if (function_exists('eStore_redirect_to_url')) {
        eStore_redirect_to_url($eStore_download_link);
    } else {
        echo '<meta http-equiv="refresh" content="0;url=' . $eStore_download_link . '" />';
    }    
}

//Check zero price setting of the product. Exit if the product doesn't have zero price.
function eStore_dnlt_do_zero_price_check($product_id){
    global $wpdb;
    $wp_eStore_config = WP_eStore_Config::getInstance();
    $products_table_name = WP_ESTORE_PRODUCTS_TABLE_NAME;
    $ret_product = $wpdb->get_row("SELECT * FROM $products_table_name WHERE id = '$product_id'", OBJECT);

    //Validate 0 price check
    if ($wp_eStore_config->getValue('eStore_product_price_must_be_zero_for_free_download') == '1') {
        if (!is_numeric($ret_product->price) || $ret_product->price > 0) {
            wp_die('<div class="eStore_error_message">Error! The admin of this site requires the product price to be set to 0.00 before it can be given as a free download!</div>');
            exit;
        }
    }
}